<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Eklenti Ekle</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Ara:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Gereç Ekle</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(aynı anda yalnızca bir örnek çalışabilir)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Paneli yapılandır</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation type="vanished">Panel boyutu</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="vanished">Boyut:</translation>
    </message>
    <message>
        <source>px</source>
        <translation type="vanished">px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation type="vanished">Otomatik boyutlandırmayı kullan</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation type="vanished">Panel uzunluğu &amp;&amp; konumu</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">Sol</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Merkez</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">Sağ</translation>
    </message>
    <message>
        <source>%</source>
        <translation type="vanished">%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation type="vanished">Yerleştirme:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation type="vanished">Uzunluk:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">Konum:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation type="vanished">Masasüstünün üst kısmı</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation type="vanished">Masaüstünün sol kısmı</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation type="vanished">Masaüstünün sağ kısmı</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation type="vanished">Masaüstünün alt kısmı</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation type="vanished">Masaüstünün üst kısmı %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation type="vanished">Masaüstünün sol kısmı %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation type="vanished">Masaüstünün sağ kısmı %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation type="vanished">Masaüstünün alt kısmı %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Paneli Yapılandır</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Gereçler</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Paneli yapılandır</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Simge boyutu:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Uzunluk:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negatif piksel değerleri panel uzunluğunu kullanılabilir ekran genişliğinden girilen piksel değeri kadar az kısaltır.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Örn: &quot;Uzunluk&quot; -100px, ekran boyutu 1000px ise gerçek panel boyutu 900px olacaktır.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Satır sayısı:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Hizalama &amp;&amp; konumu</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Sıfır animasyon yok anlamına gelir</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Animasyon süresi:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Merkez</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Özel biçemlendirme</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Yazıtipi rengi:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Arkaplan rengi:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Arkaplan matlığı:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Panel şeffaflığı için karışım gerekli.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Arkaplan resmi:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Hizalama:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Konum:</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Otomatik Gizle</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Ekranın Üstünde</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Ekranın Solunda</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Ekranın Sağında</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Ekranın Altında</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>%1 Ekranın Üstünde</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>%1 Ekranın Solunda</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>%1 Ekranın Sağında</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>%1 Ekranın Altında</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Renk seç</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Resimler(*.png *.gif *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Resim seç</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Eklentileri Yapılandır</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Not: Bu sayfada yapılan değişiklikler geri alınamaz.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Yukarı taşı</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Aşağı taşı</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Yapılandır</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1068"/>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>Paneli Yapılandır</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>Gereçleri Yönet</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>Yeni Panel Ekle</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished">Paneli Sil</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation>Bu Paneli Kilitle</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1265"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished">Paneli Sil</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1266"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Bir paneli silme eylemi geri alınamaz.
Paneli silmek istiyor musunuz?</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Paneli Sil</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation type="vanished">Paneli yapılandır...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation type="vanished">Eklenti ekle...</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation type="vanished">Yapılandır</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Taşı</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Sil</translation>
    </message>
</context>
<context>
    <name>LXQtPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation type="vanished">Paneli yapılandır</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>&quot;%1&quot; ögesini yapılandır</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>&quot;%1&quot; ögesini taşı</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>&quot;%1&quot; ögesini sil</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Diğer yapılandırma dosyasını kullanın.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Yapılandırma dosyası</translation>
    </message>
</context>
</TS>
